from flask import Flask
app = Flask(__name__)

@app.route('/')
def hello_world1():
    return 'Hello, World!'
@app.route('/100')
def hello_world2():
    return 'Hello, World!'
@app.route('/100')
def hello_world3():
    return 'Hello, World!'
@app.route('/770')
def hello_world4():
    return 'Hello, World!'
@app.route('/623')
def hello_world5():
    return 'Hello, World!'
@app.route('/303')
def hello_world6():
    return 'Hello, World!'
@app.route('/904')
def hello_world7():
    return 'Hello, World!'
@app.route('/703')
def hello_world8():
    return 'Hello, World!'
@app.route('/604')
def hello_world9():
    return 'Hello, World!'
@app.route('/504')
def hello_world10():
    return 'Hello, World!'
@app.route('/130')
def hello_world11():
    return 'Hello, World!'
@app.route('/120')
def hello_world12():
    return 'Hello, World!'
@app.route('/900')
def hello_world13():
    return 'Hello, World!'
@app.route('/800')
def hello_world14():
    return 'Hello, World!'
@app.route('/700')
def hello_world15():
    return 'Hello, World!'
@app.route('/600')
def hello_world16():
    return 'Hello, World!'
@app.route('/500')
def hello_world17():
    return 'Hello, World!'
@app.route('/400')
def hello_world18():
    return 'Hello, World!'
@app.route('/300')
def hello_world19():
    return 'Hello, World!'
@app.route('/200')
def hello_world20():
    return 'Hello, World!'
@app.route('/105')
def hello_world21():
    return 'Hello, World!'
@app.route('/104')
def hello_world22():
    return 'Hello, World!'
@app.route('/103')
def hello_world23():
    return 'Hello, World!'
@app.route('/102')
def hello_world24():
    return 'Hello, World!'
